gnash-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Gnash-commit] gnash ChangeLog libbase/Makefile.am libbase/rc....


From: Sandro Santilli
Subject: [Gnash-commit] gnash ChangeLog libbase/Makefile.am libbase/rc....
Date: Sat, 26 Apr 2008 07:58:17 +0000

CVSROOT:        /sources/gnash
Module name:    gnash
Changes by:     Sandro Santilli <strk>  08/04/26 07:58:17

Modified files:
        .              : ChangeLog 
        libbase        : Makefile.am rc.cpp 
        plugin         : Makefile.am plugin.cpp 

Log message:
                * libbase/Makefile.am: provide a SYSCONFDIR define
                * libbase/rc.cpp: use SYSCONFDIR to find gnashrc, don't guess.
                * plugin/Makefile.am: provide a SYSCONFDIR define
                * plugin/plugin.cpp: use SYSCONFIDIR to add a system-wide
                  gnashpluginrc to GNASHRC.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/gnash/ChangeLog?cvsroot=gnash&r1=1.6399&r2=1.6400
http://cvs.savannah.gnu.org/viewcvs/gnash/libbase/Makefile.am?cvsroot=gnash&r1=1.107&r2=1.108
http://cvs.savannah.gnu.org/viewcvs/gnash/libbase/rc.cpp?cvsroot=gnash&r1=1.67&r2=1.68
http://cvs.savannah.gnu.org/viewcvs/gnash/plugin/Makefile.am?cvsroot=gnash&r1=1.74&r2=1.75
http://cvs.savannah.gnu.org/viewcvs/gnash/plugin/plugin.cpp?cvsroot=gnash&r1=1.104&r2=1.105

Patches:
Index: ChangeLog
===================================================================
RCS file: /sources/gnash/gnash/ChangeLog,v
retrieving revision 1.6399
retrieving revision 1.6400
diff -u -b -r1.6399 -r1.6400
--- ChangeLog   25 Apr 2008 22:22:27 -0000      1.6399
+++ ChangeLog   26 Apr 2008 07:58:15 -0000      1.6400
@@ -1,3 +1,11 @@
+2008-04-26 Sandro Santilli <address@hidden>
+
+       * libbase/Makefile.am: provide a SYSCONFDIR define
+       * libbase/rc.cpp: use SYSCONFDIR to find gnashrc, don't guess.
+       * plugin/Makefile.am: provide a SYSCONFDIR define
+       * plugin/plugin.cpp: use SYSCONFIDIR to add a system-wide
+         gnashpluginrc to GNASHRC.
+
 2008-04-25  Dossy Shiobara <address@hidden>
 
        * configure.ac: Correctly locate windres executable when

Index: libbase/Makefile.am
===================================================================
RCS file: /sources/gnash/gnash/libbase/Makefile.am,v
retrieving revision 1.107
retrieving revision 1.108
diff -u -b -r1.107 -r1.108
--- libbase/Makefile.am 7 Apr 2008 10:59:26 -0000       1.107
+++ libbase/Makefile.am 26 Apr 2008 07:58:16 -0000      1.108
@@ -31,6 +31,7 @@
 pkglib_LTLIBRARIES =  $(LIBLTDLLIB) libgnashbase.la
 
 libgnashbase_la_CPPFLAGS = -DPLUGINSDIR=\"$(pluginsdir)\" \
+       -DSYSCONFDIR=\"$(sysconfdir)\" \
        -I.. -I$(srcdir) \
        -I$(top_srcdir) \
        -I$(top_srcdir)/libnet  \

Index: libbase/rc.cpp
===================================================================
RCS file: /sources/gnash/gnash/libbase/rc.cpp,v
retrieving revision 1.67
retrieving revision 1.68
diff -u -b -r1.67 -r1.68
--- libbase/rc.cpp      25 Apr 2008 18:14:04 -0000      1.67
+++ libbase/rc.cpp      26 Apr 2008 07:58:16 -0000      1.68
@@ -130,11 +130,8 @@
 // actually exists or not anyway.
 
     // Check the default system location
-    std::string loadfile = "/etc/gnashrc";
-    parseFile(loadfile);
-    
-    // Check the default config location
-    loadfile = "/usr/local/etc/gnashrc";
+    std::string loadfile = SYSCONFDIR;
+    loadfile.append("/gnashrc");
     parseFile(loadfile);
     
     // Check the users home directory
@@ -146,6 +143,9 @@
     }
 
     // Check the GNASHRC environment variable
+    // TODO: keep note of the already-parsed files
+    //       to avoid parsign multiple times ?
+    //       (would mess up user-reguested order)
     char *gnashrc = getenv("GNASHRC");
     if (gnashrc)
     {

Index: plugin/Makefile.am
===================================================================
RCS file: /sources/gnash/gnash/plugin/Makefile.am,v
retrieving revision 1.74
retrieving revision 1.75
diff -u -b -r1.74 -r1.75
--- plugin/Makefile.am  7 Apr 2008 14:24:27 -0000       1.74
+++ plugin/Makefile.am  26 Apr 2008 07:58:17 -0000      1.75
@@ -42,7 +42,8 @@
 # XP_UNIX      This needs to get defined for npapi.h on unix platforms.
 # PLUGIN_TRACE Enable this define to get debug prints whenever the plugin
 #              api gets control.
-AM_CPPFLAGS = -DPLUGIN_TRACE -DXP_UNIX -DMOZ_X11 -DGNASHBINDIR=\"${bindir}\" \
+AM_CPPFLAGS = -DPLUGIN_TRACE -DXP_UNIX -DMOZ_X11 -DGNASHBINDIR=\"$(bindir)\" \
+       -DSYSCONFDIR=\"$(sysconfdir)\" \
         -I.. \
         -I$(srcdir) \
         -I$(top_srcdir)/server \

Index: plugin/plugin.cpp
===================================================================
RCS file: /sources/gnash/gnash/plugin/plugin.cpp,v
retrieving revision 1.104
retrieving revision 1.105
diff -u -b -r1.104 -r1.105
--- plugin/plugin.cpp   25 Apr 2008 19:21:02 -0000      1.104
+++ plugin/plugin.cpp   26 Apr 2008 07:58:17 -0000      1.105
@@ -186,10 +186,12 @@
 
        }
 
        // Append ~/.gnashpluginrc to GNASHRC
        do {
+               // TODO: extract content in a set, add to set
+               //       and serialize back (to avoid duplicates)
+
                std::string newGnashRc;
-               bool changed = false;
                char *gnashrc = getenv("GNASHRC");
                if ( gnashrc )
                {
@@ -197,22 +199,26 @@
                        newGnashRc.append(":");
                }
 
+               newGnashRc.append(SYSCONFDIR);
+               newGnashRc.append("/gnashpluginrc");
+
                char *home = getenv("HOME");
                if ( home )
                {
+                       newGnashRc.append(":");
                        newGnashRc.append(home);
                        newGnashRc.append("/.gnashpluginrc");
                }
                else
                {
                        cerr << "WARNING: NPAPI plugin could not find user home 
dir" << endl;
-                       break;
                }
 
                if ( setenv("GNASHRC", newGnashRc.c_str(), 1) )
                {
                        cerr << "WARNING: NPAPI plugin could not append to the 
GNASHRC env variable" << endl;
                }
+               else cout << "NOTE: NPAPI plugin set GNASHRC to " << newGnashRc 
<< endl;
 
        } while (0);
@@ -186,10 +186,12 @@
        }
 
-       // Append ~/.gnashpluginrc to GNASHRC
+       // Append SYSCONFDIR/gnashpluginrc and ~/.gnashpluginrc to GNASHRC
        do {
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]